package org.dive4elements.river.artifacts.states;

import java.util.List;

import org.apache.log4j.Logger;

import org.dive4elements.artifacts.CallMeta;
import org.dive4elements.artifacts.CallContext;

import org.dive4elements.artifactdatabase.state.Facet;

import org.dive4elements.river.artifacts.FLYSArtifact;
import org.dive4elements.river.artifacts.QSectorArtifact;

import org.dive4elements.river.artifacts.model.FacetTypes;
import org.dive4elements.river.artifacts.model.QSectorFacet;

import org.dive4elements.river.artifacts.resources.Resources;

/**
 * The only state for an QSectorArtifact.
 */
public class QSectorSingleState
extends      DefaultState
implements   FacetTypes
{
    /** Developer-centric description of facet. */
    public static final String I18N_DESCRIPTION
        = "facet.qsector";

    /** The logger that is used in this state. */
    private static final Logger logger =
        Logger.getLogger(QSectorSingleState.class);


    /**
     * Add QSectorFacets to list of Facets.
     *
     * @param artifact Ignored.
     * @param hash Ignored.
     * @param meta CallMeta to be used for internationalization.
     * @param facets List to add QSectorFacet to.
     *
     * @return null.
     */
    public Object compute(
        FLYSArtifact artifact,
        String       hash,
        CallMeta     meta,
        List<Facet>  facets
    ) {
        logger.debug("QSectorSingleState.compute()");
        QSectorArtifact points = (QSectorArtifact) artifact;

        QSectorFacet qfacet = new QSectorFacet(
            0,
            QSECTOR,
            Resources.getMsg(meta, "qsectors", "Q Sectors"));

        facets.add(qfacet);

        return null;
    }


    /** Call compute. */
    @Override
    public Object computeInit(
        FLYSArtifact artifact,
        String       hash,
        Object       context,
        CallMeta     meta,
        List<Facet>  facets
     ) {
        return compute(artifact, hash, meta, facets);
    }


    /** Call compute. */
    @Override
    public Object computeFeed(
        FLYSArtifact artifact,
        String hash,
        CallContext context,
        List<Facet> facets,
        Object old
    ) {
        return compute(artifact, hash, context.getMeta(), facets);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
